## Summary

<!-- One-line description of what this PR does -->

## Changes

<!-- List the key changes -->

-
-

## Related Issues

<!-- Link related issues: Closes #123, Fixes #456 -->

## Type of Change

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to change)
- [ ] Documentation update
- [ ] Refactor / code cleanup
- [ ] CI / build / tooling

## Checklist

- [ ] Tests pass locally (`uv run pytest --tb=short -q`)
- [ ] Lint passes (`uv run ruff check .`)
- [ ] Documentation updated (if applicable)
- [ ] CHANGELOG.md updated (if user-facing change)
